# ruff: noqa: E501, PLR0915
from __future__ import annotations

types: dict[str, str] = {
    "AWS::ACMPCA::Certificate": "8095f49d3b9d3b1a",
    "AWS::ACMPCA::CertificateAuthority": "aaf234b2120b5659",
    "AWS::ACMPCA::CertificateAuthorityActivation": "a62fb980b49a2961",
    "AWS::ACMPCA::Permission": "04b877e245730b3e",
    "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus": "806adfa6e5aba057",
    "AWS::ARCZonalShift::ZonalAutoshiftConfiguration": "a2125021f0082633",
    "AWS::AccessAnalyzer::Analyzer": "3fa45a279550bbb7",
    "AWS::AmazonMQ::Broker": "c7ad1fe2fbeb2d1b",
    "AWS::AmazonMQ::Configuration": "9a9a64561c801ccb",
    "AWS::AmazonMQ::ConfigurationAssociation": "2343e0ffe1114046",
    "AWS::ApiGateway::Account": "1876f63604439391",
    "AWS::ApiGateway::ApiKey": "48205d4ffd7feba3",
    "AWS::ApiGateway::Authorizer": "2ace6030ba917092",
    "AWS::ApiGateway::BasePathMapping": "14bcf4ff90345f78",
    "AWS::ApiGateway::BasePathMappingV2": "361e364ef63cf6fd",
    "AWS::ApiGateway::ClientCertificate": "3c72d768c43d41a3",
    "AWS::ApiGateway::Deployment": "2ffb8f3345f190c2",
    "AWS::ApiGateway::DocumentationPart": "1383fef137de858b",
    "AWS::ApiGateway::DocumentationVersion": "8f19f440f5e47b9f",
    "AWS::ApiGateway::DomainName": "1b67859ef84a0247",
    "AWS::ApiGateway::DomainNameAccessAssociation": "a990644bdd54299e",
    "AWS::ApiGateway::DomainNameV2": "a0369b9dd79fc7c8",
    "AWS::ApiGateway::GatewayResponse": "1ee3349fb55bdd49",
    "AWS::ApiGateway::Method": "8d3568941b9c1cfe",
    "AWS::ApiGateway::Model": "80f210a42639b333",
    "AWS::ApiGateway::RequestValidator": "afc1110de614be93",
    "AWS::ApiGateway::Resource": "0b20e16c9c975c0d",
    "AWS::ApiGateway::RestApi": "b507ba6256e35f11",
    "AWS::ApiGateway::Stage": "56ecb180a441ee32",
    "AWS::ApiGateway::UsagePlan": "c9548a0a281386e5",
    "AWS::ApiGateway::UsagePlanKey": "309b26469128fd0a",
    "AWS::ApiGateway::VpcLink": "3c3c844926fba248",
    "AWS::ApiGatewayV2::Api": "fdc84407d8d6260e",
    "AWS::ApiGatewayV2::ApiGatewayManagedOverrides": "6852b176617879b0",
    "AWS::ApiGatewayV2::ApiMapping": "907de0790553e448",
    "AWS::ApiGatewayV2::Authorizer": "69107e1e01673765",
    "AWS::ApiGatewayV2::Deployment": "81174b55f308dad3",
    "AWS::ApiGatewayV2::DomainName": "87535a11b8340a18",
    "AWS::ApiGatewayV2::Integration": "77743451e77a7545",
    "AWS::ApiGatewayV2::IntegrationResponse": "a319db9e828555fa",
    "AWS::ApiGatewayV2::Model": "fcc09a7d8ffbd09c",
    "AWS::ApiGatewayV2::Route": "112b036b7d923f13",
    "AWS::ApiGatewayV2::RouteResponse": "3606f855415b8421",
    "AWS::ApiGatewayV2::RoutingRule": "b9e023c3c57c3c04",
    "AWS::ApiGatewayV2::Stage": "2903f59facc01e1c",
    "AWS::ApiGatewayV2::VpcLink": "e5ea6845d4e71e0b",
    "AWS::AppConfig::Application": "a84c56270dc5bf5d",
    "AWS::AppConfig::ConfigurationProfile": "d44f95228eb08d3c",
    "AWS::AppConfig::Deployment": "7a861ec5d43b4903",
    "AWS::AppConfig::DeploymentStrategy": "034671c91cf2b614",
    "AWS::AppConfig::Environment": "0c307beb222c782d",
    "AWS::AppConfig::Extension": "1c79fa5b4d27bc9a",
    "AWS::AppConfig::ExtensionAssociation": "85102348a3d001d3",
    "AWS::AppConfig::HostedConfigurationVersion": "4d2f292068fae1c6",
    "AWS::AppMesh::GatewayRoute": "f31fd0c34cd762b9",
    "AWS::AppMesh::Mesh": "375120e4ddc54cb5",
    "AWS::AppMesh::Route": "10f96fe755a3b866",
    "AWS::AppMesh::VirtualGateway": "ea8db60d40f51bd0",
    "AWS::AppMesh::VirtualNode": "bda61df49b15dd6b",
    "AWS::AppMesh::VirtualRouter": "1a8079d7b7fd931b",
    "AWS::AppMesh::VirtualService": "b6b6bd277d3b2302",
    "AWS::AppSync::Api": "b46594583c264d17",
    "AWS::AppSync::ApiCache": "d7a7fb82edccdfe2",
    "AWS::AppSync::ApiKey": "3d104ea0be48564b",
    "AWS::AppSync::ChannelNamespace": "194048f8c8383a17",
    "AWS::AppSync::DataSource": "874f010f3099ba5c",
    "AWS::AppSync::FunctionConfiguration": "f0c6eaeaf8181363",
    "AWS::AppSync::GraphQLApi": "9f7a289328001b58",
    "AWS::AppSync::GraphQLSchema": "b3409083f48d1b5b",
    "AWS::AppSync::Resolver": "f55e989a04fef713",
    "AWS::AppSync::SourceApiAssociation": "8176278e728ac6a7",
    "AWS::ApplicationAutoScaling::ScalableTarget": "de001f7e2b117e91",
    "AWS::ApplicationAutoScaling::ScalingPolicy": "9b14b927a9c342b5",
    "AWS::ApplicationInsights::Application": "4fb681541bc69d81",
    "AWS::Athena::DataCatalog": "72b7e9ce721875ee",
    "AWS::Athena::NamedQuery": "1fd9b221f87bab5d",
    "AWS::Athena::PreparedStatement": "efe18f0108881514",
    "AWS::Athena::WorkGroup": "98125aa523006e5f",
    "AWS::AutoScaling::AutoScalingGroup": "0ad094ba2f4d25b7",
    "AWS::AutoScaling::LaunchConfiguration": "138fee0bb5542e69",
    "AWS::AutoScaling::LifecycleHook": "0ee139c35778edce",
    "AWS::AutoScaling::ScalingPolicy": "68daf421ab1876df",
    "AWS::AutoScaling::ScheduledAction": "ab00e084f1d921e6",
    "AWS::AutoScaling::WarmPool": "52a6245a933ab185",
    "AWS::AutoScalingPlans::ScalingPlan": "58806bb1b0c1d2b5",
    "AWS::Backup::BackupPlan": "59655b37955d7bc9",
    "AWS::Backup::BackupSelection": "26040166156c899a",
    "AWS::Backup::BackupVault": "695e80a4aaec9275",
    "AWS::Backup::TieringConfiguration": "f16772cf7bc87fe1",
    "AWS::Batch::ComputeEnvironment": "90bfbf164c530f34",
    "AWS::Batch::ConsumableResource": "8e12226640545a9a",
    "AWS::Batch::JobDefinition": "8a7ecae4430d86b2",
    "AWS::Batch::JobQueue": "330cfa7e67eefadc",
    "AWS::Batch::SchedulingPolicy": "06201d728045e9e4",
    "AWS::Batch::ServiceEnvironment": "72c42b7d08edd4dc",
    "AWS::Budgets::Budget": "2cab89233b2339d0",
    "AWS::Budgets::BudgetsAction": "30ada2471368b7ce",
    "AWS::CDK::Metadata": "6c85ec990b9ac854",
    "AWS::CE::AnomalyMonitor": "0da3e799de4393c6",
    "AWS::CE::AnomalySubscription": "626bad41898c9c78",
    "AWS::CE::CostCategory": "02801220bf93ab09",
    "AWS::Cassandra::Keyspace": "0bd2067860b304f2",
    "AWS::Cassandra::Table": "cb4f8b935e3eae9c",
    "AWS::Cassandra::Type": "8aec046f867c1dce",
    "AWS::CertificateManager::Account": "403ae9aaf56cf1a4",
    "AWS::CertificateManager::Certificate": "215c8ed2f4fd8b1d",
    "AWS::Cloud9::EnvironmentEC2": "0d96d5a1a805b082",
    "AWS::CloudFormation::CustomResource": "e1f552bc7275a696",
    "AWS::CloudFormation::HookDefaultVersion": "ed13bf5a5bcf4773",
    "AWS::CloudFormation::HookTypeConfig": "8dac7817ef160a80",
    "AWS::CloudFormation::HookVersion": "d23903bd79b22868",
    "AWS::CloudFormation::Macro": "8517053591f9eceb",
    "AWS::CloudFormation::ModuleDefaultVersion": "0b395493be154f0d",
    "AWS::CloudFormation::ModuleVersion": "f98c4b774da7cc16",
    "AWS::CloudFormation::ResourceDefaultVersion": "f614137749ff39d3",
    "AWS::CloudFormation::ResourceVersion": "50aebd11bbf9830b",
    "AWS::CloudFormation::Stack": "089169583d0e826d",
    "AWS::CloudFormation::StackSet": "38258994c717eada",
    "AWS::CloudFormation::WaitCondition": "e62c75075457f02f",
    "AWS::CloudFormation::WaitConditionHandle": "edba290fd70976a3",
    "AWS::CloudFront::CachePolicy": "c08b3271cc175f11",
    "AWS::CloudFront::CloudFrontOriginAccessIdentity": "d2e8d397beac5797",
    "AWS::CloudFront::Distribution": "86b28a775f2612a5",
    "AWS::CloudFront::KeyGroup": "7a9f609d809f1f8e",
    "AWS::CloudFront::OriginRequestPolicy": "93db3cc24c0fa4c1",
    "AWS::CloudFront::PublicKey": "b5cac84e7e953094",
    "AWS::CloudFront::RealtimeLogConfig": "b264602b5a4f383b",
    "AWS::CloudFront::ResponseHeadersPolicy": "d5eaaa7cf7b104dc",
    "AWS::CloudFront::StreamingDistribution": "b9728ac9dbd5af28",
    "AWS::CloudTrail::Trail": "7afdcfb6fa95406a",
    "AWS::CloudWatch::Alarm": "0602d31ab163094b",
    "AWS::CloudWatch::AlarmMuteRule": "8ae4572f5b52e53d",
    "AWS::CloudWatch::AnomalyDetector": "13b8b743191bf50f",
    "AWS::CloudWatch::CompositeAlarm": "2b2200aed34aabc4",
    "AWS::CloudWatch::Dashboard": "423086b5b02bd126",
    "AWS::CloudWatch::InsightRule": "7b287284e7e98391",
    "AWS::CloudWatch::MetricStream": "ab20b9e49eb444d9",
    "AWS::CodeBuild::Project": "1da142422f2ef55c",
    "AWS::CodeBuild::ReportGroup": "b34ce85ee1e4a8da",
    "AWS::CodeBuild::SourceCredential": "b84e190d9ebbbfe1",
    "AWS::CodeCommit::Repository": "010e78acd72592c5",
    "AWS::CodeDeploy::Application": "eea8100bd279b205",
    "AWS::CodeDeploy::DeploymentConfig": "394f39ae21382747",
    "AWS::CodeDeploy::DeploymentGroup": "a5b18163cfa68275",
    "AWS::CodePipeline::CustomActionType": "b1ae4c1b735eeb9f",
    "AWS::CodePipeline::Pipeline": "ecdbe888f27625fb",
    "AWS::CodePipeline::Webhook": "a6ad2a4dc85ed032",
    "AWS::Cognito::IdentityPool": "3df22057c8e2ef54",
    "AWS::Cognito::IdentityPoolPrincipalTag": "3ae793569104c4f6",
    "AWS::Cognito::IdentityPoolRoleAttachment": "2a5296f4ca5a2ff7",
    "AWS::Config::AggregationAuthorization": "af318b77aaceeeaa",
    "AWS::Config::ConfigRule": "907ef12e35734983",
    "AWS::Config::ConfigurationAggregator": "6d45617d9786aeb6",
    "AWS::Config::ConfigurationRecorder": "e35cee148e38b939",
    "AWS::Config::DeliveryChannel": "4f7af4ff91e52582",
    "AWS::Config::OrganizationConfigRule": "1f49966ab4677d68",
    "AWS::Config::RemediationConfiguration": "1891f5fc168dbf44",
    "AWS::Config::StoredQuery": "12f2c4b9dcad23d7",
    "AWS::DLM::LifecyclePolicy": "bd3a2bfcc98bf552",
    "AWS::DMS::Certificate": "89efe57b4144e9ab",
    "AWS::DMS::DataProvider": "94c68c86840900fc",
    "AWS::DMS::Endpoint": "2e4b2c8411a3df84",
    "AWS::DMS::EventSubscription": "fdd5de7c61bc5946",
    "AWS::DMS::InstanceProfile": "b289107706553b44",
    "AWS::DMS::MigrationProject": "b4b035d4b0f0b861",
    "AWS::DMS::ReplicationConfig": "563e9b573376b7ec",
    "AWS::DMS::ReplicationInstance": "e491c749b1a4069d",
    "AWS::DMS::ReplicationSubnetGroup": "38c929d04f7ce1ee",
    "AWS::DMS::ReplicationTask": "0b9ef1a765b40e51",
    "AWS::DataBrew::Dataset": "6ab6f66c5adedaee",
    "AWS::DataBrew::Job": "489e7004ac8a0a08",
    "AWS::DataBrew::Project": "f5afe30316bff351",
    "AWS::DataBrew::Recipe": "e3f94b705b6c9421",
    "AWS::DataBrew::Ruleset": "7a2cecd2daaf227e",
    "AWS::DataBrew::Schedule": "81971b6c3ceef52e",
    "AWS::DataPipeline::Pipeline": "0200bdbc5529afe3",
    "AWS::DataSync::Agent": "68e0425ca31a7844",
    "AWS::DataSync::LocationAzureBlob": "f0cbf095b3395f82",
    "AWS::DataSync::LocationEFS": "643fd37b6ed5e6ed",
    "AWS::DataSync::LocationFSxLustre": "5ac58e3617a3ec37",
    "AWS::DataSync::LocationFSxWindows": "958c329833002c7c",
    "AWS::DataSync::LocationHDFS": "d1676e346c66185f",
    "AWS::DataSync::LocationNFS": "b4b1757a410e5e50",
    "AWS::DataSync::LocationObjectStorage": "a9c25b397b587b62",
    "AWS::DataSync::LocationS3": "b83bd659cd9ae32b",
    "AWS::DataSync::LocationSMB": "afc5e5a2496d1a84",
    "AWS::DataSync::Task": "ec59b72ff72a799c",
    "AWS::DirectConnect::Connection": "816b9e564bb15a2d",
    "AWS::DirectConnect::DirectConnectGateway": "064ba92b6e29e1bb",
    "AWS::DirectConnect::DirectConnectGatewayAssociation": "e8b6eb4a71af1eee",
    "AWS::DirectConnect::Lag": "5d6f47c1a9673feb",
    "AWS::DirectConnect::PublicVirtualInterface": "ac13a4f01149c397",
    "AWS::DirectoryService::MicrosoftAD": "9a7cb3c87d0c07fc",
    "AWS::DirectoryService::SimpleAD": "6d2510fa67236f4b",
    "AWS::DocDB::DBCluster": "be6f39b91c56eff9",
    "AWS::DocDB::DBClusterParameterGroup": "3e017448a15e0f15",
    "AWS::DocDB::DBInstance": "253562f270b587ac",
    "AWS::DocDB::DBSubnetGroup": "ccb97a9452b2284d",
    "AWS::DocDB::EventSubscription": "d22815028d03f301",
    "AWS::DynamoDB::GlobalTable": "dcad01d68f1b0691",
    "AWS::DynamoDB::Table": "50e57ed2b28d4230",
    "AWS::EC2::CapacityReservation": "1ab29c6314095182",
    "AWS::EC2::CapacityReservationFleet": "66f529dd9ae70683",
    "AWS::EC2::CustomerGateway": "5c3cdba89933c1e2",
    "AWS::EC2::DHCPOptions": "7794e3a54eaacb7a",
    "AWS::EC2::EC2Fleet": "a6921911281e83cd",
    "AWS::EC2::EIP": "cc42df82cdc81e9c",
    "AWS::EC2::EIPAssociation": "a267820d6250f189",
    "AWS::EC2::EgressOnlyInternetGateway": "922c59e19b698eac",
    "AWS::EC2::FlowLog": "ea553ae6f4a71ce3",
    "AWS::EC2::GatewayRouteTableAssociation": "50b450990964d2e7",
    "AWS::EC2::Host": "ba21ffd03e701456",
    "AWS::EC2::IPAM": "3bab32d28a4ef063",
    "AWS::EC2::IPAMAllocation": "c4cba824ca02ce4f",
    "AWS::EC2::IPAMPool": "f8632a39914b3366",
    "AWS::EC2::IPAMPoolCidr": "873e7cc6e6afef96",
    "AWS::EC2::IPAMPrefixListResolver": "475d81b7a683c9d6",
    "AWS::EC2::IPAMResourceDiscovery": "0a21294934d111b5",
    "AWS::EC2::IPAMResourceDiscoveryAssociation": "fde93486402ddbe5",
    "AWS::EC2::IPAMScope": "f1341090e0e57749",
    "AWS::EC2::Instance": "a61701d41fad1efa",
    "AWS::EC2::InstanceConnectEndpoint": "ccb7d5f817cc9d24",
    "AWS::EC2::InternetGateway": "4c7c90cb3105c9d8",
    "AWS::EC2::IpPoolRouteTableAssociation": "071b5a1f00936f72",
    "AWS::EC2::KeyPair": "349deb28f79434e4",
    "AWS::EC2::LaunchTemplate": "dbb4de05d9ee7263",
    "AWS::EC2::NatGateway": "28e80cb1fcf92145",
    "AWS::EC2::NetworkAcl": "41c7ec1cea436cd8",
    "AWS::EC2::NetworkAclEntry": "d4fc9ce8669023f0",
    "AWS::EC2::NetworkInterface": "1e436db5d46542c6",
    "AWS::EC2::NetworkInterfaceAttachment": "0d96c6d7269bdfb0",
    "AWS::EC2::NetworkInterfacePermission": "435c349a4685f2e0",
    "AWS::EC2::PlacementGroup": "8dca9ce7eb8b50ac",
    "AWS::EC2::PrefixList": "f956982a96339c09",
    "AWS::EC2::Route": "0ff811157612151a",
    "AWS::EC2::RouteTable": "67bdbfcad069c66a",
    "AWS::EC2::SecurityGroup": "5390282384be7866",
    "AWS::EC2::SecurityGroupEgress": "840df778de9b4be2",
    "AWS::EC2::SecurityGroupIngress": "367136b2f03f428c",
    "AWS::EC2::SecurityGroupVpcAssociation": "f48680388ee894fe",
    "AWS::EC2::SnapshotBlockPublicAccess": "f6434397a8c7e382",
    "AWS::EC2::SpotFleet": "b3c6b5b2f4a5b7d2",
    "AWS::EC2::Subnet": "a60b8dc0c7f50396",
    "AWS::EC2::SubnetCidrBlock": "473785ce782ba18f",
    "AWS::EC2::SubnetNetworkAclAssociation": "6b4f4042734e67b7",
    "AWS::EC2::SubnetRouteTableAssociation": "6b18db45c4ef5f57",
    "AWS::EC2::TrafficMirrorFilter": "d97085902d4e54ae",
    "AWS::EC2::TrafficMirrorFilterRule": "df0dc3904abb859c",
    "AWS::EC2::TrafficMirrorSession": "ec54e16ff79eaac0",
    "AWS::EC2::TrafficMirrorTarget": "562f502a60abccd6",
    "AWS::EC2::TransitGateway": "bdd0278ecaccd4ae",
    "AWS::EC2::TransitGatewayAttachment": "40111e00bf0df74a",
    "AWS::EC2::TransitGatewayConnect": "f3001456d8e71829",
    "AWS::EC2::TransitGatewayConnectPeer": "27459a628d254042",
    "AWS::EC2::TransitGatewayMeteringPolicy": "4daf1939996f77df",
    "AWS::EC2::TransitGatewayMeteringPolicyEntry": "153b7c0d6fcca798",
    "AWS::EC2::TransitGatewayMulticastDomain": "55ac3f0e32f72ab4",
    "AWS::EC2::TransitGatewayMulticastDomainAssociation": "f650430e0bbdcce9",
    "AWS::EC2::TransitGatewayMulticastGroupMember": "fe8c827e156dc451",
    "AWS::EC2::TransitGatewayMulticastGroupSource": "95b20156fbc77eb0",
    "AWS::EC2::TransitGatewayPeeringAttachment": "2a33a8efb207e5e5",
    "AWS::EC2::TransitGatewayRoute": "41a8efed021fd377",
    "AWS::EC2::TransitGatewayRouteTable": "cb8a1d0ac988c165",
    "AWS::EC2::TransitGatewayRouteTableAssociation": "a28bde73d4a5cde6",
    "AWS::EC2::TransitGatewayRouteTablePropagation": "e21e0c3273d49afe",
    "AWS::EC2::TransitGatewayVpcAttachment": "9f86e47a59b89462",
    "AWS::EC2::VPC": "f08626e9e82df64f",
    "AWS::EC2::VPCBlockPublicAccessExclusion": "27a1b09ed6dc90f2",
    "AWS::EC2::VPCBlockPublicAccessOptions": "1227e027d1c429f9",
    "AWS::EC2::VPCCidrBlock": "2ab876850f9f6c40",
    "AWS::EC2::VPCDHCPOptionsAssociation": "f803bdbad7d930d1",
    "AWS::EC2::VPCEndpoint": "1ece9f120d9da74a",
    "AWS::EC2::VPCEndpointConnectionNotification": "4d7f63de5d4c3a2e",
    "AWS::EC2::VPCEndpointService": "150eafe6174fc552",
    "AWS::EC2::VPCEndpointServicePermissions": "5841ea22a0cbb143",
    "AWS::EC2::VPCGatewayAttachment": "1dc77043848e8e94",
    "AWS::EC2::VPCPeeringConnection": "41b9860245304058",
    "AWS::EC2::VPNConnection": "e436dfe2cab19660",
    "AWS::EC2::VPNConnectionRoute": "d50bddcdd0369e1a",
    "AWS::EC2::VPNGateway": "1e2f029e99547e1a",
    "AWS::EC2::VPNGatewayRoutePropagation": "5e03d41fa9dc15b9",
    "AWS::EC2::Volume": "3385669f1c48cc6c",
    "AWS::EC2::VolumeAttachment": "1f1ab62c0d6b0fdb",
    "AWS::ECR::PullTimeUpdateExclusion": "67ad05acb3cd4d21",
    "AWS::ECR::RegistryPolicy": "a36a04f4454cafc2",
    "AWS::ECR::RegistryScanningConfiguration": "68012043447b437a",
    "AWS::ECR::ReplicationConfiguration": "dc2a377f75525dd4",
    "AWS::ECR::Repository": "d569f41026af3be8",
    "AWS::ECR::RepositoryCreationTemplate": "e37496e3eb934872",
    "AWS::ECS::CapacityProvider": "75072f96ae0bbe21",
    "AWS::ECS::Cluster": "92b09b679d42fc1e",
    "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
    "AWS::ECS::PrimaryTaskSet": "d8ea9e906cb85b80",
    "AWS::ECS::Service": "15d70b98c4d7b699",
    "AWS::ECS::TaskDefinition": "b9f3cf615fa7a616",
    "AWS::ECS::TaskSet": "468acfd59cd44c08",
    "AWS::EFS::AccessPoint": "48e898365c908cfd",
    "AWS::EFS::FileSystem": "575ef4f21bc6f9da",
    "AWS::EFS::MountTarget": "562530cf9ce264a6",
    "AWS::EKS::AccessEntry": "6eb6ba186799e7f3",
    "AWS::EKS::Addon": "63cae0a921c6a93d",
    "AWS::EKS::Cluster": "46cd8dea9cf6c5d7",
    "AWS::EKS::FargateProfile": "54a9efe57f089a05",
    "AWS::EKS::IdentityProviderConfig": "77b807192827540b",
    "AWS::EKS::Nodegroup": "11f90e70c2b0b5a1",
    "AWS::EKS::PodIdentityAssociation": "c9fa86f74de95001",
    "AWS::EMR::Cluster": "ac0466c8197ef416",
    "AWS::EMR::InstanceFleetConfig": "7c6308bb9ea61ce8",
    "AWS::EMR::InstanceGroupConfig": "57ea4fa9b7b6f658",
    "AWS::EMR::SecurityConfiguration": "63bc4abbfd8348f4",
    "AWS::EMR::Step": "b5416f76c2b6970c",
    "AWS::EMR::Studio": "ae37ac521793b664",
    "AWS::EMR::StudioSessionMapping": "1176f2aa157a948c",
    "AWS::EMRContainers::VirtualCluster": "d56c1799bc259539",
    "AWS::EMRServerless::Application": "ebe59c5ecbcc031b",
    "AWS::ElastiCache::CacheCluster": "1220b6bbd633ae68",
    "AWS::ElastiCache::GlobalReplicationGroup": "2af3062bf5b2cf7f",
    "AWS::ElastiCache::ParameterGroup": "b0e1dec3cd05f739",
    "AWS::ElastiCache::ReplicationGroup": "a7cce05658edb402",
    "AWS::ElastiCache::SecurityGroup": "075dfa59da275723",
    "AWS::ElastiCache::SecurityGroupIngress": "96d1b4a5bd438d25",
    "AWS::ElastiCache::ServerlessCache": "67ad14ea2425e853",
    "AWS::ElastiCache::SubnetGroup": "b331f1d336ff42bf",
    "AWS::ElastiCache::User": "e1de3c410639ffec",
    "AWS::ElastiCache::UserGroup": "13de0814cb27012a",
    "AWS::ElasticBeanstalk::Application": "e19f36d6042d03d0",
    "AWS::ElasticBeanstalk::ApplicationVersion": "6c64418c2936ab61",
    "AWS::ElasticBeanstalk::ConfigurationTemplate": "b4d2a1c4748eaf46",
    "AWS::ElasticBeanstalk::Environment": "1c992842c53a1478",
    "AWS::ElasticLoadBalancing::LoadBalancer": "0c104e32be4cf97e",
    "AWS::ElasticLoadBalancingV2::Listener": "c812f53b913442e6",
    "AWS::ElasticLoadBalancingV2::ListenerCertificate": "3edd898ae1082797",
    "AWS::ElasticLoadBalancingV2::ListenerRule": "1887769bb7b98082",
    "AWS::ElasticLoadBalancingV2::LoadBalancer": "f94791113edc7b8a",
    "AWS::ElasticLoadBalancingV2::TargetGroup": "0eedcff0831b4a32",
    "AWS::ElasticLoadBalancingV2::TrustStore": "91b22a729d45fd13",
    "AWS::ElasticLoadBalancingV2::TrustStoreRevocation": "593a78e5ca9c2be3",
    "AWS::Elasticsearch::Domain": "c6414ef13f2fedbe",
    "AWS::EventSchemas::Discoverer": "26c475458e43d0a3",
    "AWS::EventSchemas::Registry": "e90bca17695d13aa",
    "AWS::EventSchemas::RegistryPolicy": "f522642b76624a13",
    "AWS::EventSchemas::Schema": "1a9db6b605a5eee0",
    "AWS::Events::ApiDestination": "7bf90d419ff584c6",
    "AWS::Events::Archive": "6003bd8f99a7904a",
    "AWS::Events::Connection": "884ccc36565801a9",
    "AWS::Events::EventBus": "ef510d33dcc074ea",
    "AWS::Events::EventBusPolicy": "7cb0a2b18483bb52",
    "AWS::Events::Rule": "65aec73d3b811c08",
    "AWS::FMS::NotificationChannel": "3dfde465b38d83be",
    "AWS::FMS::Policy": "9a5d16a686ed3b5d",
    "AWS::FMS::ResourceSet": "6fb04db2dcf50bf8",
    "AWS::FSx::DataRepositoryAssociation": "ecfa3f43f4917224",
    "AWS::FSx::FileSystem": "9741d33840560c55",
    "AWS::FSx::Snapshot": "656a8874092132a7",
    "AWS::FSx::StorageVirtualMachine": "b62638ce430b0942",
    "AWS::FSx::Volume": "e2217632738abb7f",
    "AWS::GameLift::Alias": "4616734b4ebce44f",
    "AWS::GameLift::Build": "8f8a9acc7e4d2dd9",
    "AWS::GameLift::Fleet": "111c22065d994414",
    "AWS::GameLift::GameServerGroup": "f3daee5358a076d2",
    "AWS::GameLift::GameSessionQueue": "5503dfde9bf08e1d",
    "AWS::GameLift::MatchmakingConfiguration": "46bd22edb694e76d",
    "AWS::GameLift::MatchmakingRuleSet": "0acff3ea82d424bd",
    "AWS::GameLift::Script": "14c211c14d262f71",
    "AWS::Glue::Classifier": "e64237d854ac7fec",
    "AWS::Glue::Connection": "c1ae0f653bf6925b",
    "AWS::Glue::Crawler": "4d80d0fa90e5fedd",
    "AWS::Glue::CustomEntityType": "b46c7cf573d72e3d",
    "AWS::Glue::DataCatalogEncryptionSettings": "e4d7c9e644714bf4",
    "AWS::Glue::DataQualityRuleset": "faf8cbb22cb87066",
    "AWS::Glue::Database": "3649b59bf6fd8105",
    "AWS::Glue::DevEndpoint": "e620bcbf039ad200",
    "AWS::Glue::Job": "e7c6608d4c02d1e4",
    "AWS::Glue::MLTransform": "2c5a75b004c29815",
    "AWS::Glue::Partition": "b1116e6b758cc144",
    "AWS::Glue::Registry": "f29e746a5df78fb3",
    "AWS::Glue::Schema": "d9a6c4e12931e055",
    "AWS::Glue::SchemaVersion": "46c8ff81db63c337",
    "AWS::Glue::SchemaVersionMetadata": "e531f6334f8eeda7",
    "AWS::Glue::SecurityConfiguration": "066142ba850e9899",
    "AWS::Glue::Table": "2528cdc058dacdf8",
    "AWS::Glue::Trigger": "d61fdd6249ab4ce9",
    "AWS::Glue::Workflow": "7889f86fa2b1958f",
    "AWS::Greengrass::ConnectorDefinition": "d81a2ea631976960",
    "AWS::Greengrass::ConnectorDefinitionVersion": "8f47953c935071e4",
    "AWS::Greengrass::CoreDefinition": "15c8baf34e5f8cad",
    "AWS::Greengrass::CoreDefinitionVersion": "2693a80c8060c381",
    "AWS::Greengrass::DeviceDefinition": "6ecc6ba96c8cc79d",
    "AWS::Greengrass::DeviceDefinitionVersion": "b502a71c845a7021",
    "AWS::Greengrass::FunctionDefinition": "8fd5402cad5a731f",
    "AWS::Greengrass::FunctionDefinitionVersion": "8a246bce38603a3b",
    "AWS::Greengrass::Group": "028bdeaf7ee3b4e1",
    "AWS::Greengrass::GroupVersion": "d150ea717ebf25a3",
    "AWS::Greengrass::LoggerDefinition": "ca08580793bf92db",
    "AWS::Greengrass::LoggerDefinitionVersion": "ea84d8c626f12182",
    "AWS::Greengrass::ResourceDefinition": "346ff6094dda5ee5",
    "AWS::Greengrass::ResourceDefinitionVersion": "3162bdad8992ee5c",
    "AWS::Greengrass::SubscriptionDefinition": "b24ced07fcb36f95",
    "AWS::Greengrass::SubscriptionDefinitionVersion": "1bc9c83f06823a39",
    "AWS::GreengrassV2::ComponentVersion": "66c2ae473cdf806c",
    "AWS::GreengrassV2::Deployment": "113077f9583c552f",
    "AWS::GuardDuty::Detector": "609c5ab9768f30a4",
    "AWS::GuardDuty::Filter": "5effc026fb87131d",
    "AWS::GuardDuty::IPSet": "2755befa61203d7e",
    "AWS::GuardDuty::Master": "5115377f51b894ca",
    "AWS::GuardDuty::Member": "4410bf4350c9fdb8",
    "AWS::GuardDuty::PublishingDestination": "c0e7c21001df88a4",
    "AWS::GuardDuty::ThreatIntelSet": "41eb1d839da4d715",
    "AWS::IAM::AccessKey": "72c2d9dd90025459",
    "AWS::IAM::Group": "23f995735d09bdb9",
    "AWS::IAM::GroupPolicy": "afebc6bd2ca04f23",
    "AWS::IAM::InstanceProfile": "08ce3f200d1d387a",
    "AWS::IAM::ManagedPolicy": "1fab4f98707c4a5c",
    "AWS::IAM::OIDCProvider": "fffa104653a5e49e",
    "AWS::IAM::Policy": "a09a4b402c91ab00",
    "AWS::IAM::Role": "7fefd2b7982c788c",
    "AWS::IAM::RolePolicy": "cf758bdbc12fe737",
    "AWS::IAM::SAMLProvider": "3d4001db72ea8aee",
    "AWS::IAM::ServerCertificate": "5840107f711b833c",
    "AWS::IAM::ServiceLinkedRole": "9835b29e268f3901",
    "AWS::IAM::User": "fa88f766d15e3dd7",
    "AWS::IAM::UserPolicy": "dc178cbb13b36149",
    "AWS::IAM::UserToGroupAddition": "913f67f68af9fd37",
    "AWS::IAM::VirtualMFADevice": "9291cca6ed67f5d4",
    "AWS::IdentityStore::Group": "1b0e7a9a2bec57b5",
    "AWS::IdentityStore::GroupMembership": "d010a01463729806",
    "AWS::ImageBuilder::Component": "95f58a3a4a138e5e",
    "AWS::ImageBuilder::ContainerRecipe": "9ef7ae876461fbce",
    "AWS::ImageBuilder::DistributionConfiguration": "7b34e1b0b9958d96",
    "AWS::ImageBuilder::Image": "fea7db3bf6f817cb",
    "AWS::ImageBuilder::ImagePipeline": "b439c448d65a8542",
    "AWS::ImageBuilder::ImageRecipe": "37e69d9a511bb367",
    "AWS::ImageBuilder::InfrastructureConfiguration": "703bdd9fb961cbcd",
    "AWS::ImageBuilder::Workflow": "13db705a33e231c9",
    "AWS::IoT::AccountAuditConfiguration": "1df6ea7b44871f0a",
    "AWS::IoT::Authorizer": "af4dd52d11ab534a",
    "AWS::IoT::BillingGroup": "1326387f610a2f3e",
    "AWS::IoT::CACertificate": "777396c1bdf7b7e9",
    "AWS::IoT::Certificate": "3ecb203bd5458779",
    "AWS::IoT::CertificateProvider": "d5b9ee0a7c90a88a",
    "AWS::IoT::Command": "f618506cb529a751",
    "AWS::IoT::CustomMetric": "fbe3a13ee153328b",
    "AWS::IoT::Dimension": "7abc67aee9bdb210",
    "AWS::IoT::DomainConfiguration": "28263730be270af7",
    "AWS::IoT::EncryptionConfiguration": "04291b59f537a48b",
    "AWS::IoT::FleetMetric": "92bc802287c829a9",
    "AWS::IoT::JobTemplate": "00259d875db1b901",
    "AWS::IoT::Logging": "f6aacb672237a289",
    "AWS::IoT::MitigationAction": "c876728ee1a1d61b",
    "AWS::IoT::Policy": "b869374c681ce686",
    "AWS::IoT::PolicyPrincipalAttachment": "df0e6a915a42650b",
    "AWS::IoT::ProvisioningTemplate": "267e149317c64f1f",
    "AWS::IoT::ResourceSpecificLogging": "3472fe08f73d78f7",
    "AWS::IoT::RoleAlias": "47d4d78a34aa22b4",
    "AWS::IoT::ScheduledAudit": "985f3adc80a1fdc5",
    "AWS::IoT::SecurityProfile": "4e324e02e2bb8247",
    "AWS::IoT::SoftwarePackage": "6c7d8d10102d647b",
    "AWS::IoT::SoftwarePackageVersion": "bea41542fd802606",
    "AWS::IoT::Thing": "87d43589be8f9d6e",
    "AWS::IoT::ThingGroup": "20035a174fea8353",
    "AWS::IoT::ThingPrincipalAttachment": "cb2db377e7001773",
    "AWS::IoT::ThingType": "aad1aa827400f2b7",
    "AWS::IoT::TopicRule": "1f62598024f8c82f",
    "AWS::IoT::TopicRuleDestination": "1113af4de44b3cb0",
    "AWS::IoTAnalytics::Channel": "4b80a172cab89c05",
    "AWS::IoTAnalytics::Dataset": "89a9bd4fa1bc31e1",
    "AWS::IoTAnalytics::Datastore": "36a94ac3ef26724c",
    "AWS::IoTAnalytics::Pipeline": "06cacb1b1fc74fd8",
    "AWS::IoTEvents::AlarmModel": "c5b335fa4383da67",
    "AWS::IoTEvents::DetectorModel": "380ca6ce68ceea27",
    "AWS::IoTEvents::Input": "8e563556d54e2664",
    "AWS::IoTSiteWise::AccessPolicy": "f690f40383e9244b",
    "AWS::IoTSiteWise::Asset": "e6593f4ce2a789df",
    "AWS::IoTSiteWise::AssetModel": "ab693f673bacba74",
    "AWS::IoTSiteWise::Dashboard": "39a4967569772e8b",
    "AWS::IoTSiteWise::Gateway": "6ed022f32e5bccd6",
    "AWS::IoTSiteWise::Portal": "26930262cd495116",
    "AWS::IoTSiteWise::Project": "b07f2cb698b5d6b2",
    "AWS::IoTTwinMaker::ComponentType": "4047916d6f25a52d",
    "AWS::IoTTwinMaker::Entity": "87cfb0f09e609346",
    "AWS::IoTTwinMaker::Scene": "fef394e5c8e7cd21",
    "AWS::IoTTwinMaker::SyncJob": "b030f1432b8d2813",
    "AWS::IoTTwinMaker::Workspace": "c35a3fb5877a42a7",
    "AWS::KMS::Alias": "28f10f922a4d194f",
    "AWS::KMS::Key": "c70e396ee12ddb65",
    "AWS::KMS::ReplicaKey": "903f43e74c8d8853",
    "AWS::KafkaConnect::Connector": "02c89e2c1eb3d4f3",
    "AWS::KafkaConnect::CustomPlugin": "b57a0879af8759b3",
    "AWS::KafkaConnect::WorkerConfiguration": "1f80a6b9f1a4d5be",
    "AWS::Kinesis::ResourcePolicy": "39996915810e234a",
    "AWS::Kinesis::Stream": "8ebde19042fda1b6",
    "AWS::Kinesis::StreamConsumer": "7ce125c877a406e0",
    "AWS::KinesisAnalytics::Application": "50ae263f846c3862",
    "AWS::KinesisAnalytics::ApplicationOutput": "639fc1050aa8a059",
    "AWS::KinesisAnalytics::ApplicationReferenceDataSource": "8cda34a806d77b86",
    "AWS::KinesisAnalyticsV2::Application": "b62bfa34fbb059a5",
    "AWS::KinesisAnalyticsV2::ApplicationCloudWatchLoggingOption": "e07193f9ce1d04dc",
    "AWS::KinesisAnalyticsV2::ApplicationOutput": "14bce3d20b063bd9",
    "AWS::KinesisAnalyticsV2::ApplicationReferenceDataSource": "f9ca29a27845c82d",
    "AWS::KinesisFirehose::DeliveryStream": "9c8f3215b7dfb3ab",
    "AWS::LakeFormation::DataCellsFilter": "6ac217ac96918929",
    "AWS::LakeFormation::DataLakeSettings": "d9b68c11de60cdd0",
    "AWS::LakeFormation::Permissions": "062fc8932c9970c4",
    "AWS::LakeFormation::PrincipalPermissions": "89fd48f71918cde3",
    "AWS::LakeFormation::Resource": "64382446e2262067",
    "AWS::LakeFormation::Tag": "e6965562c3f7e5bb",
    "AWS::LakeFormation::TagAssociation": "22d7f7ee98ca2b17",
    "AWS::Lambda::Alias": "7eaea7897e54c75a",
    "AWS::Lambda::EventInvokeConfig": "c30b1c987d66f67f",
    "AWS::Lambda::EventSourceMapping": "80b93fa5c6ca4992",
    "AWS::Lambda::Function": "3a6aacfd45065c20",
    "AWS::Lambda::LayerVersion": "f00fbc621c084236",
    "AWS::Lambda::LayerVersionPermission": "3d77aa7f6f48b060",
    "AWS::Lambda::Permission": "a43a5328bea4f6ad",
    "AWS::Lambda::Url": "cd116e62a210bc57",
    "AWS::Lambda::Version": "e7fcd54deb138582",
    "AWS::LaunchWizard::Deployment": "2532c1afdd9c1f65",
    "AWS::Logs::AccountPolicy": "b8c495155e0407f4",
    "AWS::Logs::Delivery": "c87395bbed1a6b98",
    "AWS::Logs::DeliveryDestination": "30b61a3515971eda",
    "AWS::Logs::DeliverySource": "67b64320b397d6cd",
    "AWS::Logs::Destination": "ff1e6b020f2cf8e7",
    "AWS::Logs::LogGroup": "953bd0bd1515ac76",
    "AWS::Logs::LogStream": "91035e555c3110ac",
    "AWS::Logs::MetricFilter": "4b4400caff5cc44e",
    "AWS::Logs::QueryDefinition": "7b82b12db189c1d9",
    "AWS::Logs::ResourcePolicy": "d7898253a7730ac3",
    "AWS::Logs::SubscriptionFilter": "c1ec900772212dcf",
    "AWS::MSK::BatchScramSecret": "ff2b807a577495b0",
    "AWS::MSK::Cluster": "d2642928d6736e1c",
    "AWS::MSK::ClusterPolicy": "b60740da22ea8c04",
    "AWS::MSK::Configuration": "61dbb22c2b6cbbb1",
    "AWS::MSK::Replicator": "e4c147fed22ae544",
    "AWS::MSK::Topic": "7c3b1270fbb7dbf8",
    "AWS::MSK::VpcConnection": "6aeb07916b90c80a",
    "AWS::MWAA::Environment": "c28ab3624f1d638c",
    "AWS::MemoryDB::ACL": "be62545f5a3ca571",
    "AWS::MemoryDB::Cluster": "bdff729237d834d8",
    "AWS::MemoryDB::ParameterGroup": "ee0d490ded2bd32d",
    "AWS::MemoryDB::SubnetGroup": "1ebef44f5b8af50d",
    "AWS::MemoryDB::User": "f144b50282e8c3ea",
    "AWS::Neptune::DBCluster": "8d9215c18d4689e5",
    "AWS::Neptune::DBClusterParameterGroup": "d3f072d3d16a7a5f",
    "AWS::Neptune::DBInstance": "40928fad97bbb2cd",
    "AWS::Neptune::DBParameterGroup": "6b2f9cd1b2702ccf",
    "AWS::Neptune::DBSubnetGroup": "c59d053f84ba853c",
    "AWS::Neptune::EventSubscription": "291cb01f3cbffb3e",
    "AWS::NetworkFirewall::Firewall": "5734de8d83f8ab9a",
    "AWS::NetworkFirewall::FirewallPolicy": "23d185da5cfdceca",
    "AWS::NetworkFirewall::LoggingConfiguration": "24065655a3066a83",
    "AWS::NetworkFirewall::RuleGroup": "0a775a8261b19aad",
    "AWS::NetworkFirewall::TLSInspectionConfiguration": "c67eab10509c4b9d",
    "AWS::NetworkFirewall::VpcEndpointAssociation": "671a5fc51bc59b14",
    "AWS::Oam::Link": "4d4e114e0f615d82",
    "AWS::Oam::Sink": "81957ea027e4c201",
    "AWS::OpenSearchService::Domain": "9066691d16aebb93",
    "AWS::OpsWorks::App": "508d500b32261320",
    "AWS::OpsWorks::ElasticLoadBalancerAttachment": "4902f6030931194b",
    "AWS::OpsWorks::Instance": "eb6dd86e61f421da",
    "AWS::OpsWorks::Layer": "ce4434f184dbda87",
    "AWS::OpsWorks::Stack": "29ffdc808f9c83e1",
    "AWS::OpsWorks::UserProfile": "c81a3392e657795c",
    "AWS::OpsWorks::Volume": "2de519e2f08e58bd",
    "AWS::Organizations::Account": "5e4fa45032c79057",
    "AWS::Organizations::Organization": "ef5f3cbaa91637bd",
    "AWS::Organizations::OrganizationalUnit": "48f9a21ef5f81812",
    "AWS::Organizations::Policy": "91a30b5718ac046b",
    "AWS::Organizations::ResourcePolicy": "44e0f38bebacad2e",
    "AWS::Personalize::Dataset": "d0f930319da6b133",
    "AWS::Personalize::DatasetGroup": "a9925a53c157b6e3",
    "AWS::Personalize::Schema": "a82320a3520e6fc6",
    "AWS::Personalize::Solution": "32129ea1039bfbbe",
    "AWS::Pipes::Pipe": "ef04c5b621766de2",
    "AWS::QuickSight::Analysis": "ea70d53eb8cdc617",
    "AWS::QuickSight::CustomPermissions": "da6da182c0c23fb4",
    "AWS::QuickSight::Dashboard": "b1b7368590994f86",
    "AWS::QuickSight::DataSet": "29bb159e7e1e87fc",
    "AWS::QuickSight::DataSource": "407708b753626383",
    "AWS::QuickSight::Folder": "4a9e4af92dbcc718",
    "AWS::QuickSight::RefreshSchedule": "0e848e5d85a17427",
    "AWS::QuickSight::Template": "bf2e53263bce9387",
    "AWS::QuickSight::Theme": "c85a23cc7ca1d55e",
    "AWS::QuickSight::VPCConnection": "bb1c6b99877fb6ba",
    "AWS::RAM::Permission": "978c532747f94c7b",
    "AWS::RAM::ResourceShare": "b4b5ff31bc5f95b0",
    "AWS::RDS::DBCluster": "9c7540d3d4699497",
    "AWS::RDS::DBClusterParameterGroup": "4e3460620664c07f",
    "AWS::RDS::DBInstance": "25726c9e8467f4c5",
    "AWS::RDS::DBParameterGroup": "d29cf38b861f6048",
    "AWS::RDS::DBProxy": "308e70305b33a892",
    "AWS::RDS::DBProxyEndpoint": "17943cc672d084c2",
    "AWS::RDS::DBProxyTargetGroup": "b584b6fb42fcd4c7",
    "AWS::RDS::DBSecurityGroup": "42f555e782cd9946",
    "AWS::RDS::DBSecurityGroupIngress": "1a14ad6e73c0b6b7",
    "AWS::RDS::DBShardGroup": "df6b36c7e099595a",
    "AWS::RDS::DBSubnetGroup": "4a2ab41cbcc2adb8",
    "AWS::RDS::EventSubscription": "85bf3af749d312f0",
    "AWS::RDS::GlobalCluster": "a87d030f06c19d47",
    "AWS::RDS::Integration": "b41a67e5adeb023f",
    "AWS::RDS::OptionGroup": "d89f528bd7bdd696",
    "AWS::Rbin::Rule": "7302f3e4816f5e9e",
    "AWS::Redshift::Cluster": "24380b75d618dc41",
    "AWS::Redshift::ClusterParameterGroup": "5eafb174c8375f06",
    "AWS::Redshift::ClusterSecurityGroup": "6a629309a94b6faa",
    "AWS::Redshift::ClusterSecurityGroupIngress": "0079cffa4eeb3685",
    "AWS::Redshift::ClusterSubnetGroup": "5c5ef039a548a325",
    "AWS::Redshift::EndpointAccess": "c8b246db37a986a0",
    "AWS::Redshift::EndpointAuthorization": "e72be424d109da1d",
    "AWS::Redshift::EventSubscription": "636e5903e3e73299",
    "AWS::Redshift::Integration": "ea8ecb64062e3355",
    "AWS::Redshift::ScheduledAction": "8f8f379cd2fdb2bc",
    "AWS::RedshiftServerless::Namespace": "5713f5387741d15b",
    "AWS::RedshiftServerless::Snapshot": "826c5d08e248c956",
    "AWS::RedshiftServerless::Workgroup": "d725f73083591093",
    "AWS::ResourceGroups::Group": "7be20625159a2551",
    "AWS::RolesAnywhere::CRL": "f52a01aa06e590f5",
    "AWS::RolesAnywhere::Profile": "e6cb05cf67e91208",
    "AWS::RolesAnywhere::TrustAnchor": "3add0281e203381f",
    "AWS::Route53::CidrCollection": "2332f11a72446133",
    "AWS::Route53::HealthCheck": "92f14427097812fb",
    "AWS::Route53::HostedZone": "ff22e0187d9beac4",
    "AWS::Route53::RecordSet": "c01e9eccec2e3b83",
    "AWS::Route53::RecordSetGroup": "0f70c9c554987b2d",
    "AWS::Route53Profiles::Profile": "1d89ef4356c426b4",
    "AWS::Route53Profiles::ProfileAssociation": "fa568e44f7d9e9f2",
    "AWS::Route53Profiles::ProfileResourceAssociation": "73d6b9da50afa75b",
    "AWS::Route53Resolver::FirewallDomainList": "47cc5f401e1f9bbe",
    "AWS::Route53Resolver::FirewallRuleGroup": "bee6df8eb043a885",
    "AWS::Route53Resolver::FirewallRuleGroupAssociation": "d84c68a6ebbb5876",
    "AWS::Route53Resolver::ResolverConfig": "174be26547caaa42",
    "AWS::Route53Resolver::ResolverDNSSECConfig": "813fd8fe1e24c6e3",
    "AWS::Route53Resolver::ResolverEndpoint": "fc74be0ae84138f0",
    "AWS::Route53Resolver::ResolverQueryLoggingConfig": "896173cca4e29ac8",
    "AWS::Route53Resolver::ResolverQueryLoggingConfigAssociation": "41e93f940f8bce93",
    "AWS::Route53Resolver::ResolverRule": "455bd6c59c07fb7b",
    "AWS::Route53Resolver::ResolverRuleAssociation": "3e5cdfc8643c083b",
    "AWS::S3::AccessGrant": "b1e7af0495a078b0",
    "AWS::S3::AccessGrantsInstance": "05d3e874b43bbad8",
    "AWS::S3::AccessGrantsLocation": "3a7be1727f630029",
    "AWS::S3::AccessPoint": "e8b95810dd8d6917",
    "AWS::S3::Bucket": "f2e96ae4922bbb57",
    "AWS::S3::BucketPolicy": "38ad5b8bd8062535",
    "AWS::S3::StorageLens": "842abc50870a3bcf",
    "AWS::S3::StorageLensGroup": "a48c03e67d334c14",
    "AWS::S3Express::AccessPoint": "319fc2700104fd70",
    "AWS::S3Express::BucketPolicy": "79c6732ff6204662",
    "AWS::S3Express::DirectoryBucket": "06fdc76e1b66a21f",
    "AWS::S3ObjectLambda::AccessPoint": "2d6b2b82a9508114",
    "AWS::S3ObjectLambda::AccessPointPolicy": "fd6328c6c782223a",
    "AWS::S3Tables::Namespace": "148f9286df26a384",
    "AWS::S3Tables::Table": "06c0bb9325f0bc8c",
    "AWS::S3Tables::TableBucket": "c87800af01ff17ff",
    "AWS::S3Tables::TableBucketPolicy": "8a4df56718b22c4c",
    "AWS::S3Tables::TablePolicy": "a400a63607882bc8",
    "AWS::SDB::Domain": "48c38397df169b43",
    "AWS::SNS::Subscription": "9426c559a25e9da6",
    "AWS::SNS::Topic": "210149c7ee544cd1",
    "AWS::SNS::TopicInlinePolicy": "e47e6b028a7c3cc7",
    "AWS::SNS::TopicPolicy": "04470a92c9a1130c",
    "AWS::SQS::Queue": "4b3c7b55a266949b",
    "AWS::SQS::QueueInlinePolicy": "e4132d6c68dcbc6c",
    "AWS::SQS::QueuePolicy": "8d0c3b8154e71ff3",
    "AWS::SSM::Association": "e5ce83b562338270",
    "AWS::SSM::Document": "fafd81d675e3af92",
    "AWS::SSM::MaintenanceWindow": "067c502e88a1f5d2",
    "AWS::SSM::MaintenanceWindowTarget": "1d59aec599d718b8",
    "AWS::SSM::MaintenanceWindowTask": "dbf020e1bce02a1c",
    "AWS::SSM::Parameter": "88998b8e50aa846a",
    "AWS::SSM::PatchBaseline": "43cce065b6753223",
    "AWS::SSM::ResourceDataSync": "f92ce1aa6674b7f2",
    "AWS::SSO::Application": "996ad386536ff750",
    "AWS::SSO::ApplicationAssignment": "ae6daf9e56a38982",
    "AWS::SSO::Assignment": "3e0b05f0a3cba8d8",
    "AWS::SSO::Instance": "12637265e4117853",
    "AWS::SSO::InstanceAccessControlAttributeConfiguration": "ccfedd9599046cb1",
    "AWS::SSO::PermissionSet": "e4212a96dd4b627d",
    "AWS::SageMaker::App": "48a84d4277803da3",
    "AWS::SageMaker::AppImageConfig": "0500a25b2fd80213",
    "AWS::SageMaker::CodeRepository": "d59f5cf4521ff1c2",
    "AWS::SageMaker::Domain": "c2a82bf359890cfa",
    "AWS::SageMaker::Endpoint": "bcd29d1fafd461ae",
    "AWS::SageMaker::EndpointConfig": "7c3a65bd96c2e9a3",
    "AWS::SageMaker::FeatureGroup": "2fd87c841fd87a48",
    "AWS::SageMaker::Image": "564da26f07cd2046",
    "AWS::SageMaker::ImageVersion": "307ec283c9c38549",
    "AWS::SageMaker::Model": "9757bf2bdc6a25ef",
    "AWS::SageMaker::ModelCard": "89534938581c1015",
    "AWS::SageMaker::ModelPackage": "20d340cd288752de",
    "AWS::SageMaker::MonitoringSchedule": "741bf90cf6ce8312",
    "AWS::SageMaker::NotebookInstance": "f222a6268560b3b6",
    "AWS::SageMaker::NotebookInstanceLifecycleConfig": "f0d21af114094fa4",
    "AWS::SageMaker::Pipeline": "d0698ac81fb18f57",
    "AWS::SageMaker::ProcessingJob": "e1994976600f5bae",
    "AWS::SageMaker::Project": "a659dd2080a26111",
    "AWS::SageMaker::StudioLifecycleConfig": "5654680d7015fbd4",
    "AWS::SageMaker::UserProfile": "0b1d6e7b47d96c39",
    "AWS::SageMaker::Workteam": "d617e40122a8fe93",
    "AWS::Scheduler::Schedule": "e8b60514af25a837",
    "AWS::Scheduler::ScheduleGroup": "ef710d09dbb243bf",
    "AWS::SecretsManager::ResourcePolicy": "cb5d330bf15d9d5a",
    "AWS::SecretsManager::RotationSchedule": "e02692fb717f1c08",
    "AWS::SecretsManager::Secret": "ea029b329dc57364",
    "AWS::SecretsManager::SecretTargetAttachment": "3bf4404734c82308",
    "AWS::SecurityHub::AutomationRule": "f42a9d0542caf822",
    "AWS::SecurityHub::ConfigurationPolicy": "4db5271b2e19d197",
    "AWS::SecurityHub::DelegatedAdmin": "a328fc62a9f2f7e2",
    "AWS::SecurityHub::FindingAggregator": "7a4c95623ee48fcd",
    "AWS::SecurityHub::Hub": "9f6cb2d8967bfcf6",
    "AWS::SecurityHub::Insight": "6c43c37d361a91ef",
    "AWS::SecurityHub::OrganizationConfiguration": "494d5bdaaa99a7a9",
    "AWS::SecurityHub::PolicyAssociation": "fe287d4170e40018",
    "AWS::SecurityHub::ProductSubscription": "a6a7b09a786ba544",
    "AWS::SecurityHub::SecurityControl": "062ab72de4bbcd1d",
    "AWS::SecurityHub::Standard": "a9a57a7527f5aff5",
    "AWS::ServiceCatalog::AcceptedPortfolioShare": "77373a56c0c4bd28",
    "AWS::ServiceCatalog::CloudFormationProduct": "662186534ff8e643",
    "AWS::ServiceCatalog::CloudFormationProvisionedProduct": "448a377417beb2e5",
    "AWS::ServiceCatalog::LaunchNotificationConstraint": "b7978856af5cccf2",
    "AWS::ServiceCatalog::LaunchRoleConstraint": "645835eeed030de3",
    "AWS::ServiceCatalog::LaunchTemplateConstraint": "e457535596ed60a2",
    "AWS::ServiceCatalog::Portfolio": "546acc3272366c1a",
    "AWS::ServiceCatalog::PortfolioPrincipalAssociation": "c1655e6cd9e94bc0",
    "AWS::ServiceCatalog::PortfolioProductAssociation": "39311ae1cb0b583e",
    "AWS::ServiceCatalog::PortfolioShare": "c365f2118140f92b",
    "AWS::ServiceCatalog::ResourceUpdateConstraint": "9ddbc905c8a71617",
    "AWS::ServiceCatalog::StackSetConstraint": "34cef71a3b8b5ea3",
    "AWS::ServiceCatalog::TagOption": "0a7e7604f593ea6c",
    "AWS::ServiceCatalog::TagOptionAssociation": "932ff2b84208a648",
    "AWS::ServiceDiscovery::HttpNamespace": "986cb51cac464fe8",
    "AWS::ServiceDiscovery::Instance": "b4227e1dfa14a394",
    "AWS::ServiceDiscovery::PrivateDnsNamespace": "d78a2213969ef282",
    "AWS::ServiceDiscovery::PublicDnsNamespace": "da152fa1f7dce966",
    "AWS::ServiceDiscovery::Service": "cc0f82ca0c9cf09a",
    "AWS::StepFunctions::Activity": "b3156a89a45815e1",
    "AWS::StepFunctions::StateMachine": "f6e6ebffca5675b3",
    "AWS::StepFunctions::StateMachineAlias": "55cc66ee1f33c9f5",
    "AWS::StepFunctions::StateMachineVersion": "4467293a52255b78",
    "AWS::Synthetics::Canary": "a553d010d467c6ed",
    "AWS::Transfer::Agreement": "1013512feba974f8",
    "AWS::Transfer::Certificate": "f7478973edec7bd3",
    "AWS::Transfer::Connector": "8827021611524252",
    "AWS::Transfer::Profile": "88c7478695f7c070",
    "AWS::Transfer::Server": "90b633961fce2a5f",
    "AWS::Transfer::User": "7dbec614b03c1346",
    "AWS::Transfer::WebApp": "146273f9ed9978d6",
    "AWS::Transfer::Workflow": "851674d5732910da",
    "AWS::VerifiedPermissions::Policy": "f7e75c34791cf6a5",
    "AWS::VerifiedPermissions::PolicyStore": "d797894a95fb9d61",
    "AWS::VerifiedPermissions::PolicyTemplate": "067128efc0e8f2eb",
    "AWS::WAF::ByteMatchSet": "bdac58da17fc8f67",
    "AWS::WAF::IPSet": "e9b5a4840b312167",
    "AWS::WAF::Rule": "2eb380e895f6c1fe",
    "AWS::WAF::SizeConstraintSet": "7b4d9b8017b0288e",
    "AWS::WAF::SqlInjectionMatchSet": "392352f8be8c6258",
    "AWS::WAF::WebACL": "347318598f8787e2",
    "AWS::WAF::XssMatchSet": "ac4c34fbea311314",
    "AWS::WAFRegional::ByteMatchSet": "994da0cf8bd3e164",
    "AWS::WAFRegional::GeoMatchSet": "02fe4746f224ce16",
    "AWS::WAFRegional::IPSet": "44ebba581bb9b196",
    "AWS::WAFRegional::RateBasedRule": "4e4d503472dd02e8",
    "AWS::WAFRegional::RegexPatternSet": "bec049612963886e",
    "AWS::WAFRegional::Rule": "1b5eeb744e2eb869",
    "AWS::WAFRegional::SizeConstraintSet": "2020060b93f50b79",
    "AWS::WAFRegional::SqlInjectionMatchSet": "e934a6dec5e807ed",
    "AWS::WAFRegional::WebACL": "375f1db4fc74a74e",
    "AWS::WAFRegional::WebACLAssociation": "f6cb657edbe28837",
    "AWS::WAFRegional::XssMatchSet": "d06f5257461f5e67",
    "AWS::WAFv2::IPSet": "fe4bc7d488064ebc",
    "AWS::WAFv2::LoggingConfiguration": "219a7415589ec0bf",
    "AWS::WAFv2::RegexPatternSet": "71e5110f182eba06",
    "AWS::WAFv2::RuleGroup": "17c881f134c11dbb",
    "AWS::WAFv2::WebACL": "27eb9031e644a7fd",
    "AWS::WAFv2::WebACLAssociation": "f47dba384d872bb3",
    "AWS::WorkSpaces::Workspace": "95eec1aff41966b4",
    "AWS::XRay::Group": "9e6b73a50d7628e1",
    "AWS::XRay::ResourcePolicy": "1eefd10339461fe6",
    "AWS::XRay::SamplingRule": "78c8dff3096127b9",
    "Module": "baab0e57f109673a",
}
